# -*- coding: utf-8 -*-
# Generated by Django 1.9.4 on 2016-03-08 16:36
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Make',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('description', models.TextField(default='')),
                ('last_modified', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Model',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('years', models.CharField(max_length=64)),
                ('description', models.TextField(default='')),
                ('last_modified', models.DateTimeField(auto_now=True)),
                ('make', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bikestats.Make')),
            ],
        ),
        migrations.CreateModel(
            name='Stat',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=64)),
                ('value', models.CharField(max_length=64)),
                ('model', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bikestats.Model')),
            ],
        ),
        migrations.AlterUniqueTogether(
            name='make',
            unique_together=set([('name',)]),
        ),
        migrations.AlterUniqueTogether(
            name='stat',
            unique_together=set([('name', 'model')]),
        ),
        migrations.AlterUniqueTogether(
            name='model',
            unique_together=set([('name', 'make', 'years')]),
        ),
    ]
